/****************************************************************************
** Meta object code from reading C++ file 'lxqtrotatedwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/liblxqt-0.11.0/lxqtrotatedwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lxqtrotatedwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_LXQt__RotatedWidget_t {
    QByteArrayData data[10];
    char stringdata0[198];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LXQt__RotatedWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LXQt__RotatedWidget_t qt_meta_stringdata_LXQt__RotatedWidget = {
    {
QT_MOC_LITERAL(0, 0, 19), // "LXQt::RotatedWidget"
QT_MOC_LITERAL(1, 20, 6), // "origin"
QT_MOC_LITERAL(2, 27, 10), // "Qt::Corner"
QT_MOC_LITERAL(3, 38, 23), // "transferMousePressEvent"
QT_MOC_LITERAL(4, 62, 25), // "transferMouseReleaseEvent"
QT_MOC_LITERAL(5, 88, 29), // "transferMouseDoubleClickEvent"
QT_MOC_LITERAL(6, 118, 22), // "transferMouseMoveEvent"
QT_MOC_LITERAL(7, 141, 18), // "transferWheelEvent"
QT_MOC_LITERAL(8, 160, 18), // "transferEnterEvent"
QT_MOC_LITERAL(9, 179, 18) // "transferLeaveEvent"

    },
    "LXQt::RotatedWidget\0origin\0Qt::Corner\0"
    "transferMousePressEvent\0"
    "transferMouseReleaseEvent\0"
    "transferMouseDoubleClickEvent\0"
    "transferMouseMoveEvent\0transferWheelEvent\0"
    "transferEnterEvent\0transferLeaveEvent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LXQt__RotatedWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       8,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, 0x80000000 | 2, 0x0009510b,
       3, QMetaType::Bool, 0x00095103,
       4, QMetaType::Bool, 0x00095103,
       5, QMetaType::Bool, 0x00095103,
       6, QMetaType::Bool, 0x00095103,
       7, QMetaType::Bool, 0x00095103,
       8, QMetaType::Bool, 0x00095103,
       9, QMetaType::Bool, 0x00095103,

       0        // eod
};

void LXQt::RotatedWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        RotatedWidget *_t = static_cast<RotatedWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Qt::Corner*>(_v) = _t->origin(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->transferMousePressEvent(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->transferMouseReleaseEvent(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->transferMouseDoubleClickEvent(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->transferMouseMoveEvent(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->transferWheelEvent(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->transferEnterEvent(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->transferLeaveEvent(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        RotatedWidget *_t = static_cast<RotatedWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOrigin(*reinterpret_cast< Qt::Corner*>(_v)); break;
        case 1: _t->setTransferMousePressEvent(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setTransferMouseReleaseEvent(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setTransferMouseDoubleClickEvent(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setTransferMouseMoveEvent(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setTransferWheelEvent(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setTransferEnterEvent(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setTransferLeaveEvent(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject LXQt::RotatedWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_LXQt__RotatedWidget.data,
      qt_meta_data_LXQt__RotatedWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *LXQt::RotatedWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LXQt::RotatedWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_LXQt__RotatedWidget.stringdata0))
        return static_cast<void*>(const_cast< RotatedWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int LXQt::RotatedWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
   if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_END_MOC_NAMESPACE
